Struct hypn_gameset::CreateCoin
source[−]pub struct CreateCoin<'info> {
pub coin: AccountLoader<'info, Coin>,
pub vault: Account<'info, Vault>,
pub requester: AccountInfo<'info>,
pub initiator: AccountInfo<'info>,
pub acceptor: AccountInfo<'info>,
pub oracle: AccountInfo<'info>,
pub oracle_vault: AccountInfo<'info>,
pub solrand_program: AccountInfo<'info>,
pub rent: Sysvar<'info, Rent>,
pub system_program: Program<'info, System>,
}Fields
coin: AccountLoader<'info, Coin>vault: Account<'info, Vault>requester: AccountInfo<'info>initiator: AccountInfo<'info>acceptor: AccountInfo<'info>oracle: AccountInfo<'info>oracle_vault: AccountInfo<'info>solrand_program: AccountInfo<'info>rent: Sysvar<'info, Rent>system_program: Program<'info, System>Trait Implementations
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read more
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more